irl\_benchmark.rl.algorithms package
====================================

Submodules
----------

irl\_benchmark.rl.algorithms.base\_algorithm module
---------------------------------------------------

.. automodule:: irl_benchmark.rl.algorithms.base_algorithm
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.rl.algorithms.random\_agent module
-------------------------------------------------

.. automodule:: irl_benchmark.rl.algorithms.random_agent
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.rl.algorithms.value\_iteration module
----------------------------------------------------

.. automodule:: irl_benchmark.rl.algorithms.value_iteration
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: irl_benchmark.rl.algorithms
    :members:
    :undoc-members:
    :show-inheritance:
